package com.ruoyi.oa.mapper;

import java.util.List;
import com.ruoyi.oa.domain.CmcDeposit;

/**
 * cmc保证金审批Mapper接口
 * 
 * @author cmc
 * @date 2024-04-29
 */
public interface CmcDepositMapper 
{
    /**
     * 查询cmc保证金审批
     * 
     * @param depositId cmc保证金审批主键
     * @return cmc保证金审批
     */
    public CmcDeposit selectCmcDepositByDepositId(String depositId);

    /**
     * 查询cmc保证金审批列表
     * 
     * @param cmcDeposit cmc保证金审批
     * @return cmc保证金审批集合
     */
    public List<CmcDeposit> selectCmcDepositList(CmcDeposit cmcDeposit);

    /**
     * 新增cmc保证金审批
     * 
     * @param cmcDeposit cmc保证金审批
     * @return 结果
     */
    public int insertCmcDeposit(CmcDeposit cmcDeposit);

    /**
     * 修改cmc保证金审批
     * 
     * @param cmcDeposit cmc保证金审批
     * @return 结果
     */
    public int updateCmcDeposit(CmcDeposit cmcDeposit);

    /**
     * 删除cmc保证金审批
     * 
     * @param depositId cmc保证金审批主键
     * @return 结果
     */
    public int deleteCmcDepositByDepositId(String depositId);

    /**
     * 批量删除cmc保证金审批
     * 
     * @param depositIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCmcDepositByDepositIds(String[] depositIds);
}
